@@ -9,6 +9,8 @@ import (
 	"syscall"
 	"time"
 
+	"github.com/cloudskiff/driftctl/pkg/analyser"
+	"github.com/cloudskiff/driftctl/pkg/memstore"
 	"github.com/cloudskiff/driftctl/pkg/remote/common"
 	"github.com/cloudskiff/driftctl/pkg/telemetry"
 	"github.com/fatih/color"
@@ -32,7 +34,7 @@ import (
 )
 
 func NewScanCmd() *cobra.Command {
-	opts := &pkg.ScanOptions{Deep: true}
+	opts := &pkg.ScanOptions{}
 	opts.BackendOptions = &backend.Options{}
 
 	cmd := &cobra.Command{
@@ -98,6 +100,8 @@ func NewScanCmd() *cobra.Command {
 		},
 	}
 
+	warn := color.New(color.FgYellow, color.Bold).SprintfFunc()
+
 	fl := cmd.Flags()
 	fl.Bool(
 		"quiet",
@@ -159,6 +163,12 @@ func NewScanCmd() *cobra.Command {
 		false,
 		"Includes cloud provider service-linked roles (disabled by default)",
 	)
+	fl.BoolVar(&opts.Deep,
+		"deep",
+		false,
+		fmt.Sprintf("%s Enable deep mode\n", warn("EXPERIMENTAL:"))+
+			"You should check the documentation for more details: https://docs.driftctl.com/deep-mode\n",
+	)
 	fl.StringVar(&opts.DriftignorePath,
 		"driftignore",
 		".driftignore",
@@ -179,6 +189,7 @@ func NewScanCmd() *cobra.Command {
 }
 
 func scanRun(opts *pkg.ScanOptions) error {
+	store := memstore.New()
 	selectedOutput := output.GetOutput(opts.Output, opts.Quiet)
 
 	c := make(chan os.Signal)
@@ -187,7 +198,6 @@ func scanRun(opts *pkg.ScanOptions) error {
 	alerter := alerter.NewAlerter()
 
 	providerLibrary := terraform.NewProviderLibrary()
-	supplierLibrary := resource.NewSupplierLibrary()
 	remoteLibrary := common.NewRemoteLibrary()
 
 	iacProgress := globaloutput.NewProgress("Scanning states", "Scanned states", true)
@@ -197,7 +207,7 @@ func scanRun(opts *pkg.ScanOptions) error {
 
 	resFactory := terraform.NewTerraformResourceFactory(resourceSchemaRepository)
 
-	err := remote.Activate(opts.To, opts.ProviderVersion, alerter, providerLibrary, supplierLibrary, remoteLibrary, scanProgress, resourceSchemaRepository, resFactory, opts.ConfigDir)
+	err := remote.Activate(opts.To, opts.ProviderVersion, alerter, providerLibrary, remoteLibrary, scanProgress, resourceSchemaRepository, resFactory, opts.ConfigDir)
 	if err != nil {
 		return err
 	}
@@ -209,14 +219,28 @@ func scanRun(opts *pkg.ScanOptions) error {
 		logrus.Trace("Exited")
 	}()
 
-	scanner := remote.NewScanner(supplierLibrary.Suppliers(), remoteLibrary, alerter, remote.ScannerOptions{Deep: opts.Deep})
+	logrus.Debug("Checking for driftignore")
+	driftIgnore := filter.NewDriftIgnore(opts.DriftignorePath)
+
+	scanner := remote.NewScanner(remoteLibrary, alerter, remote.ScannerOptions{Deep: opts.Deep})
 
 	iacSupplier, err := supplier.GetIACSupplier(opts.From, providerLibrary, opts.BackendOptions, iacProgress, resFactory)
 	if err != nil {
 		return err
 	}
 
-	ctl := pkg.NewDriftCTL(scanner, iacSupplier, alerter, resFactory, opts, scanProgress, iacProgress, resourceSchemaRepository)
+	ctl := pkg.NewDriftCTL(
+		scanner,
+		iacSupplier,
+		alerter,
+		analyser.NewAnalyzer(alerter, analyser.AnalyzerOptions{Deep: opts.Deep}, driftIgnore),
+		resFactory,
+		opts,
+		scanProgress,
+		iacProgress,
+		resourceSchemaRepository,
+		store,
+	)
 
 	go func() {
 		<-c
@@ -235,13 +259,12 @@ func scanRun(opts *pkg.ScanOptions) error {
 	}
 
 	globaloutput.Printf(color.WhiteString("Scan duration: %s\n", analysis.Duration.Round(time.Second)))
+	globaloutput.Printf(color.WhiteString("Provider version used to scan: %s. Use --tf-provider-version to use another version.\n"), resourceSchemaRepository.ProviderVersion.String())
 
 	if !opts.DisableTelemetry {
-		telemetry.SendTelemetry(analysis)
+		telemetry.SendTelemetry(store.Bucket(memstore.TelemetryBucket))
 	}
 
-	globaloutput.Printf(color.WhiteString("Provider version used to scan: %s. Use --tf-provider-version to use another version.\n"), resourceSchemaRepository.ProviderVersion.String())
-
 	if !analysis.IsSync() {
 		globaloutput.Printf("\nHint: use gen-driftignore command to generate a .driftignore file based on your drifts\n")
 
