@@ -8,6 +8,7 @@ import (
 	"github.com/cloudskiff/driftctl/pkg/alerter"
 	"github.com/cloudskiff/driftctl/pkg/analyser"
 	"github.com/cloudskiff/driftctl/pkg/filter"
+	"github.com/cloudskiff/driftctl/pkg/memstore"
 	"github.com/cloudskiff/driftctl/pkg/output"
 	"github.com/cloudskiff/driftctl/pkg/resource"
 	"github.com/cloudskiff/driftctl/pkg/resource/aws"
@@ -16,6 +17,7 @@ import (
 	"github.com/cloudskiff/driftctl/test"
 	testresource "github.com/cloudskiff/driftctl/test/resource"
 	"github.com/r3labs/diff/v2"
+	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/mock"
 )
 
@@ -30,7 +32,8 @@ type TestCase struct {
 	stateResources  []resource.Resource
 	remoteResources []resource.Resource
 	mocks           func(factory resource.ResourceFactory, repo resource.SchemaRepositoryInterface)
-	assert          func(result *test.ScanResult, err error)
+	assert          func(t *testing.T, result *test.ScanResult, err error)
+	assertStore     func(*testing.T, memstore.Store)
 	options         *pkg.ScanOptions
 }
 
@@ -98,11 +101,21 @@ func runTest(t *testing.T, cases TestCases) {
 			iacProgress.On("Start").Return().Once()
 			iacProgress.On("Stop").Return().Once()
 
-			driftctl := pkg.NewDriftCTL(remoteSupplier, stateSupplier, testAlerter, resourceFactory, c.options, scanProgress, iacProgress, repo)
+			testFilter := &filter.MockFilter{}
+			testFilter.On("IsTypeIgnored", mock.Anything).Return(false)
+			testFilter.On("IsResourceIgnored", mock.Anything).Return(false)
+			testFilter.On("IsFieldIgnored", mock.Anything, mock.Anything).Return(false)
+			analyzer := analyser.NewAnalyzer(testAlerter, analyser.AnalyzerOptions{Deep: c.options.Deep}, testFilter)
+
+			store := memstore.New()
+			driftctl := pkg.NewDriftCTL(remoteSupplier, stateSupplier, testAlerter, analyzer, resourceFactory, c.options, scanProgress, iacProgress, repo, store)
 
 			analysis, err := driftctl.Run()
 
-			c.assert(test.NewScanResult(t, analysis), err)
+			c.assert(t, test.NewScanResult(t, analysis), err)
+			if c.assertStore != nil {
+				c.assertStore(t, store)
+			}
 			scanProgress.AssertExpectations(t)
 		})
 	}
@@ -124,9 +137,14 @@ func TestDriftctlRun_BasicBehavior(t *testing.T) {
 			name:            "analysis duration is set",
 			stateResources:  []resource.Resource{},
 			remoteResources: []resource.Resource{},
-			assert: func(result *test.ScanResult, err error) {
+			assert: func(t *testing.T, result *test.ScanResult, err error) {
 				result.NotZero(result.Duration)
 			},
+			assertStore: func(t *testing.T, store memstore.Store) {
+				assert.Equal(t, 0, store.Bucket(memstore.TelemetryBucket).Get("total_resources"))
+				assert.Equal(t, 0, store.Bucket(memstore.TelemetryBucket).Get("total_managed"))
+				assert.Equal(t, uint(0), store.Bucket(memstore.TelemetryBucket).Get("duration"))
+			},
 		},
 		{
 			name: "infrastructure should be in sync",
@@ -136,9 +154,14 @@ func TestDriftctlRun_BasicBehavior(t *testing.T) {
 			remoteResources: []resource.Resource{
 				&testresource.FakeResource{},
 			},
-			assert: func(result *test.ScanResult, err error) {
+			assert: func(t *testing.T, result *test.ScanResult, err error) {
 				result.AssertInfrastructureIsInSync()
 			},
+			assertStore: func(t *testing.T, store memstore.Store) {
+				assert.Equal(t, 1, store.Bucket(memstore.TelemetryBucket).Get("total_resources"))
+				assert.Equal(t, 1, store.Bucket(memstore.TelemetryBucket).Get("total_managed"))
+				assert.Equal(t, uint(0), store.Bucket(memstore.TelemetryBucket).Get("duration"))
+			},
 			options: func(t *testing.T) *pkg.ScanOptions {
 				return &pkg.ScanOptions{Deep: true}
 			}(t),
@@ -149,9 +172,14 @@ func TestDriftctlRun_BasicBehavior(t *testing.T) {
 				&testresource.FakeResource{},
 			},
 			remoteResources: []resource.Resource{},
-			assert: func(result *test.ScanResult, err error) {
+			assert: func(t *testing.T, result *test.ScanResult, err error) {
 				result.AssertDeletedCount(1)
 			},
+			assertStore: func(t *testing.T, store memstore.Store) {
+				assert.Equal(t, 1, store.Bucket(memstore.TelemetryBucket).Get("total_resources"))
+				assert.Equal(t, 0, store.Bucket(memstore.TelemetryBucket).Get("total_managed"))
+				assert.Equal(t, uint(0), store.Bucket(memstore.TelemetryBucket).Get("duration"))
+			},
 		},
 		{
 			name:           "we should have unmanaged resource",
@@ -159,9 +187,14 @@ func TestDriftctlRun_BasicBehavior(t *testing.T) {
 			remoteResources: []resource.Resource{
 				&testresource.FakeResource{},
 			},
-			assert: func(result *test.ScanResult, err error) {
+			assert: func(t *testing.T, result *test.ScanResult, err error) {
 				result.AssertUnmanagedCount(1)
 			},
+			assertStore: func(t *testing.T, store memstore.Store) {
+				assert.Equal(t, 1, store.Bucket(memstore.TelemetryBucket).Get("total_resources"))
+				assert.Equal(t, 0, store.Bucket(memstore.TelemetryBucket).Get("total_managed"))
+				assert.Equal(t, uint(0), store.Bucket(memstore.TelemetryBucket).Get("duration"))
+			},
 		},
 		{
 			name: "we should have changes of field update",
@@ -181,7 +214,7 @@ func TestDriftctlRun_BasicBehavior(t *testing.T) {
 					},
 				},
 			},
-			assert: func(result *test.ScanResult, err error) {
+			assert: func(t *testing.T, result *test.ScanResult, err error) {
 				result.AssertManagedCount(1)
 				result.AssertResourceHasDrift("fake", "FakeResource", analyser.Change{
 					Change: diff.Change{
@@ -193,6 +226,11 @@ func TestDriftctlRun_BasicBehavior(t *testing.T) {
 					Computed: false,
 				})
 			},
+			assertStore: func(t *testing.T, store memstore.Store) {
+				assert.Equal(t, 1, store.Bucket(memstore.TelemetryBucket).Get("total_resources"))
+				assert.Equal(t, 1, store.Bucket(memstore.TelemetryBucket).Get("total_managed"))
+				assert.Equal(t, uint(0), store.Bucket(memstore.TelemetryBucket).Get("duration"))
+			},
 		},
 		{
 			name: "we should have changes on computed field",
@@ -214,7 +252,7 @@ func TestDriftctlRun_BasicBehavior(t *testing.T) {
 					},
 				},
 			},
-			assert: func(result *test.ScanResult, err error) {
+			assert: func(t *testing.T, result *test.ScanResult, err error) {
 				result.AssertManagedCount(1)
 				result.AssertResourceHasDrift("fake", aws.AwsAmiResourceType, analyser.Change{
 					Change: diff.Change{
@@ -226,6 +264,11 @@ func TestDriftctlRun_BasicBehavior(t *testing.T) {
 					Computed: true,
 				})
 			},
+			assertStore: func(t *testing.T, store memstore.Store) {
+				assert.Equal(t, 1, store.Bucket(memstore.TelemetryBucket).Get("total_resources"))
+				assert.Equal(t, 1, store.Bucket(memstore.TelemetryBucket).Get("total_managed"))
+				assert.Equal(t, uint(0), store.Bucket(memstore.TelemetryBucket).Get("duration"))
+			},
 		},
 		{
 			name: "we should have changes on deleted field",
@@ -247,7 +290,7 @@ func TestDriftctlRun_BasicBehavior(t *testing.T) {
 					},
 				},
 			},
-			assert: func(result *test.ScanResult, err error) {
+			assert: func(t *testing.T, result *test.ScanResult, err error) {
 				result.AssertManagedCount(1)
 				result.AssertResourceHasDrift("fake", "FakeResource", analyser.Change{
 					Change: diff.Change{
@@ -259,6 +302,11 @@ func TestDriftctlRun_BasicBehavior(t *testing.T) {
 					Computed: false,
 				})
 			},
+			assertStore: func(t *testing.T, store memstore.Store) {
+				assert.Equal(t, 1, store.Bucket(memstore.TelemetryBucket).Get("total_resources"))
+				assert.Equal(t, 1, store.Bucket(memstore.TelemetryBucket).Get("total_managed"))
+				assert.Equal(t, uint(0), store.Bucket(memstore.TelemetryBucket).Get("duration"))
+			},
 		},
 		{
 			name: "we should have changes of added field",
@@ -280,7 +328,7 @@ func TestDriftctlRun_BasicBehavior(t *testing.T) {
 					},
 				},
 			},
-			assert: func(result *test.ScanResult, err error) {
+			assert: func(t *testing.T, result *test.ScanResult, err error) {
 				result.AssertManagedCount(1)
 				result.AssertResourceHasDrift("fake", "FakeResource", analyser.Change{
 					Change: diff.Change{
@@ -292,6 +340,11 @@ func TestDriftctlRun_BasicBehavior(t *testing.T) {
 					Computed: false,
 				})
 			},
+			assertStore: func(t *testing.T, store memstore.Store) {
+				assert.Equal(t, 1, store.Bucket(memstore.TelemetryBucket).Get("total_resources"))
+				assert.Equal(t, 1, store.Bucket(memstore.TelemetryBucket).Get("total_managed"))
+				assert.Equal(t, uint(0), store.Bucket(memstore.TelemetryBucket).Get("duration"))
+			},
 		},
 		{
 			name: "we should ignore default AWS IAM role when strict mode is disabled",
@@ -369,12 +422,17 @@ func TestDriftctlRun_BasicBehavior(t *testing.T) {
 					},
 				},
 			},
-			assert: func(result *test.ScanResult, err error) {
+			assert: func(t *testing.T, result *test.ScanResult, err error) {
 				result.AssertManagedCount(2)
 				result.AssertUnmanagedCount(2)
 				result.AssertDeletedCount(0)
 				result.AssertDriftCountTotal(0)
 			},
+			assertStore: func(t *testing.T, store memstore.Store) {
+				assert.Equal(t, 4, store.Bucket(memstore.TelemetryBucket).Get("total_resources"))
+				assert.Equal(t, 2, store.Bucket(memstore.TelemetryBucket).Get("total_managed"))
+				assert.Equal(t, uint(0), store.Bucket(memstore.TelemetryBucket).Get("duration"))
+			},
 			options: func(t *testing.T) *pkg.ScanOptions {
 				return &pkg.ScanOptions{
 					StrictMode: false,
@@ -458,12 +516,17 @@ func TestDriftctlRun_BasicBehavior(t *testing.T) {
 					},
 				},
 			},
-			assert: func(result *test.ScanResult, err error) {
+			assert: func(t *testing.T, result *test.ScanResult, err error) {
 				result.AssertManagedCount(2)
 				result.AssertUnmanagedCount(4)
 				result.AssertDeletedCount(0)
 				result.AssertDriftCountTotal(0)
 			},
+			assertStore: func(t *testing.T, store memstore.Store) {
+				assert.Equal(t, 6, store.Bucket(memstore.TelemetryBucket).Get("total_resources"))
+				assert.Equal(t, 2, store.Bucket(memstore.TelemetryBucket).Get("total_managed"))
+				assert.Equal(t, uint(0), store.Bucket(memstore.TelemetryBucket).Get("duration"))
+			},
 			options: func(t *testing.T) *pkg.ScanOptions {
 				return &pkg.ScanOptions{
 					StrictMode: true,
@@ -547,7 +610,7 @@ func TestDriftctlRun_BasicBehavior(t *testing.T) {
 					},
 				},
 			},
-			assert: func(result *test.ScanResult, err error) {
+			assert: func(t *testing.T, result *test.ScanResult, err error) {
 				result.AssertCoverage(0)
 				result.AssertInfrastructureIsNotSync()
 				result.AssertManagedCount(0)
@@ -555,6 +618,11 @@ func TestDriftctlRun_BasicBehavior(t *testing.T) {
 				result.AssertDeletedCount(0)
 				result.AssertDriftCountTotal(0)
 			},
+			assertStore: func(t *testing.T, store memstore.Store) {
+				assert.Equal(t, 1, store.Bucket(memstore.TelemetryBucket).Get("total_resources"))
+				assert.Equal(t, 0, store.Bucket(memstore.TelemetryBucket).Get("total_managed"))
+				assert.Equal(t, uint(0), store.Bucket(memstore.TelemetryBucket).Get("duration"))
+			},
 			options: func(t *testing.T) *pkg.ScanOptions {
 				filterStr := "Id=='role-test-1'"
 				f, err := filter.BuildExpression(filterStr)
@@ -591,7 +659,7 @@ func TestDriftctlRun_BasicFilter(t *testing.T) {
 					Attrs: &resource.Attributes{},
 				},
 			},
-			assert: func(result *test.ScanResult, err error) {
+			assert: func(t *testing.T, result *test.ScanResult, err error) {
 				result.AssertUnmanagedCount(1)
 				result.AssertResourceUnmanaged("res2", "filtered")
 			},
@@ -620,7 +688,7 @@ func TestDriftctlRun_BasicFilter(t *testing.T) {
 					Attrs: &resource.Attributes{},
 				},
 			},
-			assert: func(result *test.ScanResult, err error) {
+			assert: func(t *testing.T, result *test.ScanResult, err error) {
 				result.AssertUnmanagedCount(1)
 				result.AssertResourceUnmanaged("res2", "filtered")
 			},
@@ -651,7 +719,7 @@ func TestDriftctlRun_BasicFilter(t *testing.T) {
 					Attrs: &resource.Attributes{},
 				},
 			},
-			assert: func(result *test.ScanResult, err error) {
+			assert: func(t *testing.T, result *test.ScanResult, err error) {
 				result.AssertUnmanagedCount(1)
 				result.AssertResourceUnmanaged("res1", "filtered")
 			},
@@ -716,7 +784,7 @@ func TestDriftctlRun_Middlewares(t *testing.T) {
 					Sch: getSchema(repo, aws.AwsS3BucketPolicyResourceType),
 				})
 			},
-			assert: func(result *test.ScanResult, err error) {
+			assert: func(t *testing.T, result *test.ScanResult, err error) {
 				result.AssertManagedCount(1)
 				result.AssertResourceHasDrift("foo", "aws_s3_bucket_policy", analyser.Change{
 					Change: diff.Change{
@@ -821,7 +889,7 @@ func TestDriftctlRun_Middlewares(t *testing.T) {
 					})
 				})).Times(1).Return(&bar, nil)
 			},
-			assert: func(result *test.ScanResult, err error) {
+			assert: func(t *testing.T, result *test.ScanResult, err error) {
 				result.AssertManagedCount(2)
 				result.AssertResourceHasDrift("vol-02862d9b39045a3a4", "aws_ebs_volume", analyser.Change{
 					Change: diff.Change{
@@ -937,7 +1005,7 @@ func TestDriftctlRun_Middlewares(t *testing.T) {
 					},
 				}, nil)
 			},
-			assert: func(result *test.ScanResult, err error) {
+			assert: func(t *testing.T, result *test.ScanResult, err error) {
 				result.AssertManagedCount(2)
 				result.AssertInfrastructureIsInSync()
 			},
@@ -991,7 +1059,7 @@ func TestDriftctlRun_Middlewares(t *testing.T) {
 					Sch: getSchema(repo, aws.AwsSnsTopicPolicyResourceType),
 				}, nil)
 			},
-			assert: func(result *test.ScanResult, err error) {
+			assert: func(t *testing.T, result *test.ScanResult, err error) {
 				result.AssertManagedCount(1)
 				result.AssertResourceHasDrift("foo", "aws_sns_topic_policy", analyser.Change{
 					Change: diff.Change{
@@ -1053,7 +1121,7 @@ func TestDriftctlRun_Middlewares(t *testing.T) {
 					Sch: getSchema(repo, aws.AwsSqsQueuePolicyResourceType),
 				}, nil)
 			},
-			assert: func(result *test.ScanResult, err error) {
+			assert: func(t *testing.T, result *test.ScanResult, err error) {
 				result.AssertManagedCount(1)
 				result.AssertResourceHasDrift("foo", "aws_sqs_queue_policy", analyser.Change{
 					Change: diff.Change{
@@ -1378,7 +1446,7 @@ func TestDriftctlRun_Middlewares(t *testing.T) {
 						})
 					})).Times(1).Return(&rule4, nil)
 			},
-			assert: func(result *test.ScanResult, err error) {
+			assert: func(t *testing.T, result *test.ScanResult, err error) {
 				result.AssertManagedCount(7)
 				result.AssertInfrastructureIsInSync()
 			},
@@ -1516,7 +1584,7 @@ func TestDriftctlRun_Middlewares(t *testing.T) {
 					},
 				}, nil)
 			},
-			assert: func(result *test.ScanResult, err error) {
+			assert: func(t *testing.T, result *test.ScanResult, err error) {
 				result.AssertManagedCount(2)
 				result.AssertInfrastructureIsInSync()
 			},
@@ -1600,7 +1668,7 @@ func TestDriftctlRun_Middlewares(t *testing.T) {
 					Attrs: &resource.Attributes{},
 				},
 			},
-			assert: func(result *test.ScanResult, err error) {
+			assert: func(t *testing.T, result *test.ScanResult, err error) {
 				result.AssertInfrastructureIsInSync()
 				result.AssertManagedCount(5)
 			},
@@ -1679,7 +1747,7 @@ func TestDriftctlRun_Middlewares(t *testing.T) {
 					},
 				},
 			},
-			assert: func(result *test.ScanResult, err error) {
+			assert: func(t *testing.T, result *test.ScanResult, err error) {
 				result.AssertInfrastructureIsInSync()
 				result.AssertManagedCount(5)
 			},
