@@ -31,7 +31,7 @@ func (e *Route53RecordEnumerator) Enumerate() ([]resource.Resource, error) {
 
 	zones, err := e.client.ListAllZones()
 	if err != nil {
-		return nil, remoteerror.NewResourceEnumerationErrorWithType(err, resourceaws.AwsRoute53RecordResourceType, resourceaws.AwsRoute53ZoneResourceType)
+		return nil, remoteerror.NewResourceEnumerationErrorWithType(err, string(e.SupportedType()), resourceaws.AwsRoute53ZoneResourceType)
 	}
 
 	results := make([]resource.Resource, len(zones))
@@ -39,7 +39,7 @@ func (e *Route53RecordEnumerator) Enumerate() ([]resource.Resource, error) {
 	for _, hostedZone := range zones {
 		records, err := e.listRecordsForZone(strings.TrimPrefix(*hostedZone.Id, "/hostedzone/"))
 		if err != nil {
-			return nil, remoteerror.NewResourceEnumerationError(err, resourceaws.AwsRoute53RecordResourceType)
+			return nil, remoteerror.NewResourceEnumerationError(err, string(e.SupportedType()))
 		}
 
 		results = append(results, records...)
@@ -76,7 +76,9 @@ func (e *Route53RecordEnumerator) listRecordsForZone(zoneId string) ([]resource.
 			e.factory.CreateAbstractResource(
 				string(e.SupportedType()),
 				strings.Join(vars, "_"),
-				map[string]interface{}{},
+				map[string]interface{}{
+					"type": rawType,
+				},
 			),
 		)
 	}
