@@ -101,7 +101,7 @@ func TestEC2EbsVolume(t *testing.T) {
 			remoteLibrary.AddEnumerator(aws.NewEC2EbsVolumeEnumerator(repo, factory))
 			remoteLibrary.AddDetailsFetcher(resourceaws.AwsEbsVolumeResourceType, common.NewGenericDetailsFetcher(resourceaws.AwsEbsVolumeResourceType, provider, deserializer))
 
-			s := NewScanner(nil, remoteLibrary, alerter, scanOptions)
+			s := NewScanner(remoteLibrary, alerter, scanOptions)
 			got, err := s.Resources()
 			assert.Equal(tt, err, c.wantErr)
 			if err != nil {
@@ -190,7 +190,7 @@ func TestEC2EbsSnapshot(t *testing.T) {
 			remoteLibrary.AddEnumerator(aws.NewEC2EbsSnapshotEnumerator(repo, factory))
 			remoteLibrary.AddDetailsFetcher(resourceaws.AwsEbsSnapshotResourceType, common.NewGenericDetailsFetcher(resourceaws.AwsEbsSnapshotResourceType, provider, deserializer))
 
-			s := NewScanner(nil, remoteLibrary, alerter, scanOptions)
+			s := NewScanner(remoteLibrary, alerter, scanOptions)
 			got, err := s.Resources()
 			assert.Equal(tt, err, c.wantErr)
 			if err != nil {
@@ -279,7 +279,7 @@ func TestEC2Eip(t *testing.T) {
 			remoteLibrary.AddEnumerator(aws.NewEC2EipEnumerator(repo, factory))
 			remoteLibrary.AddDetailsFetcher(resourceaws.AwsEipResourceType, common.NewGenericDetailsFetcher(resourceaws.AwsEipResourceType, provider, deserializer))
 
-			s := NewScanner(nil, remoteLibrary, alerter, scanOptions)
+			s := NewScanner(remoteLibrary, alerter, scanOptions)
 			got, err := s.Resources()
 			assert.Equal(tt, err, c.wantErr)
 			if err != nil {
@@ -368,7 +368,7 @@ func TestEC2Ami(t *testing.T) {
 			remoteLibrary.AddEnumerator(aws.NewEC2AmiEnumerator(repo, factory))
 			remoteLibrary.AddDetailsFetcher(resourceaws.AwsAmiResourceType, common.NewGenericDetailsFetcher(resourceaws.AwsAmiResourceType, provider, deserializer))
 
-			s := NewScanner(nil, remoteLibrary, alerter, scanOptions)
+			s := NewScanner(remoteLibrary, alerter, scanOptions)
 			got, err := s.Resources()
 			assert.Equal(tt, err, c.wantErr)
 			if err != nil {
@@ -457,7 +457,7 @@ func TestEC2KeyPair(t *testing.T) {
 			remoteLibrary.AddEnumerator(aws.NewEC2KeyPairEnumerator(repo, factory))
 			remoteLibrary.AddDetailsFetcher(resourceaws.AwsKeyPairResourceType, common.NewGenericDetailsFetcher(resourceaws.AwsKeyPairResourceType, provider, deserializer))
 
-			s := NewScanner(nil, remoteLibrary, alerter, scanOptions)
+			s := NewScanner(remoteLibrary, alerter, scanOptions)
 			got, err := s.Resources()
 			assert.Equal(tt, err, c.wantErr)
 			if err != nil {
@@ -479,15 +479,18 @@ func TestEC2EipAssociation(t *testing.T) {
 			test:    "no eip associations",
 			dirName: "aws_ec2_eip_association_empty",
 			mocks: func(repository *repository.MockEC2Repository) {
-				repository.On("ListAllAddressesAssociation").Return([]string{}, nil)
+				repository.On("ListAllAddressesAssociation").Return([]*ec2.Address{}, nil)
 			},
 		},
 		{
 			test:    "single eip association",
 			dirName: "aws_ec2_eip_association_single",
 			mocks: func(repository *repository.MockEC2Repository) {
-				repository.On("ListAllAddressesAssociation").Return([]string{
-					"eipassoc-0e9a7356e30f0c3d1",
+				repository.On("ListAllAddressesAssociation").Return([]*ec2.Address{
+					{
+						AssociationId: awssdk.String("eipassoc-0e9a7356e30f0c3d1"),
+						AllocationId:  awssdk.String("eipalloc-017d5267e4dda73f1"),
+					},
 				}, nil)
 			},
 		},
@@ -545,7 +548,7 @@ func TestEC2EipAssociation(t *testing.T) {
 			remoteLibrary.AddEnumerator(aws.NewEC2EipAssociationEnumerator(repo, factory))
 			remoteLibrary.AddDetailsFetcher(resourceaws.AwsEipAssociationResourceType, common.NewGenericDetailsFetcher(resourceaws.AwsEipAssociationResourceType, provider, deserializer))
 
-			s := NewScanner(nil, remoteLibrary, alerter, scanOptions)
+			s := NewScanner(remoteLibrary, alerter, scanOptions)
 			got, err := s.Resources()
 			assert.Equal(tt, err, c.wantErr)
 			if err != nil {
@@ -642,9 +645,9 @@ func TestEC2Instance(t *testing.T) {
 			}
 
 			remoteLibrary.AddEnumerator(aws.NewEC2InstanceEnumerator(repo, factory))
-			remoteLibrary.AddDetailsFetcher(resourceaws.AwsInstanceResourceType, aws.NewEC2InstanceDetailsFetcher(provider, deserializer))
+			remoteLibrary.AddDetailsFetcher(resourceaws.AwsInstanceResourceType, common.NewGenericDetailsFetcher(resourceaws.AwsInstanceResourceType, provider, deserializer))
 
-			s := NewScanner(nil, remoteLibrary, alerter, scanOptions)
+			s := NewScanner(remoteLibrary, alerter, scanOptions)
 			got, err := s.Resources()
 			assert.Equal(tt, err, c.wantErr)
 			if err != nil {
@@ -733,7 +736,7 @@ func TestEC2InternetGateway(t *testing.T) {
 			remoteLibrary.AddEnumerator(aws.NewEC2InternetGatewayEnumerator(repo, factory))
 			remoteLibrary.AddDetailsFetcher(resourceaws.AwsInternetGatewayResourceType, common.NewGenericDetailsFetcher(resourceaws.AwsInternetGatewayResourceType, provider, deserializer))
 
-			s := NewScanner(nil, remoteLibrary, alerter, scanOptions)
+			s := NewScanner(remoteLibrary, alerter, scanOptions)
 			got, err := s.Resources()
 			assert.Equal(tt, err, c.wantErr)
 			if err != nil {
@@ -804,7 +807,7 @@ func TestVPC(t *testing.T) {
 		t.Run(c.test, func(tt *testing.T) {
 			shouldUpdate := c.dirName == *goldenfile.Update
 
-			session := session.Must(session.NewSessionWithOptions(session.Options{
+			sess := session.Must(session.NewSessionWithOptions(session.Options{
 				SharedConfigState: session.SharedConfigEnable,
 			}))
 
@@ -833,13 +836,13 @@ func TestVPC(t *testing.T) {
 					t.Fatal(err)
 				}
 				provider.ShouldUpdate()
-				repo = repository.NewEC2Repository(session, cache.New(0))
+				repo = repository.NewEC2Repository(sess, cache.New(0))
 			}
 
 			remoteLibrary.AddEnumerator(aws.NewVPCEnumerator(repo, factory))
 			remoteLibrary.AddDetailsFetcher(resourceaws.AwsVpcResourceType, common.NewGenericDetailsFetcher(resourceaws.AwsVpcResourceType, provider, deserializer))
 
-			s := NewScanner(nil, remoteLibrary, alerter, scanOptions)
+			s := NewScanner(remoteLibrary, alerter, scanOptions)
 			got, err := s.Resources()
 			assert.Equal(tt, err, c.wantErr)
 			if err != nil {
@@ -907,7 +910,7 @@ func TestDefaultVPC(t *testing.T) {
 		t.Run(c.test, func(tt *testing.T) {
 			shouldUpdate := c.dirName == *goldenfile.Update
 
-			session := session.Must(session.NewSessionWithOptions(session.Options{
+			sess := session.Must(session.NewSessionWithOptions(session.Options{
 				SharedConfigState: session.SharedConfigEnable,
 			}))
 
@@ -936,13 +939,13 @@ func TestDefaultVPC(t *testing.T) {
 					t.Fatal(err)
 				}
 				provider.ShouldUpdate()
-				repo = repository.NewEC2Repository(session, cache.New(0))
+				repo = repository.NewEC2Repository(sess, cache.New(0))
 			}
 
 			remoteLibrary.AddEnumerator(aws.NewDefaultVPCEnumerator(repo, factory))
 			remoteLibrary.AddDetailsFetcher(resourceaws.AwsDefaultVpcResourceType, common.NewGenericDetailsFetcher(resourceaws.AwsDefaultVpcResourceType, provider, deserializer))
 
-			s := NewScanner(nil, remoteLibrary, alerter, scanOptions)
+			s := NewScanner(remoteLibrary, alerter, scanOptions)
 			got, err := s.Resources()
 			assert.Equal(tt, err, c.wantErr)
 			if err != nil {
@@ -1100,7 +1103,7 @@ func TestEC2RouteTableAssociation(t *testing.T) {
 			remoteLibrary.AddEnumerator(aws.NewEC2RouteTableAssociationEnumerator(repo, factory))
 			remoteLibrary.AddDetailsFetcher(resourceaws.AwsRouteTableAssociationResourceType, aws.NewEC2RouteTableAssociationDetailsFetcher(provider, deserializer))
 
-			s := NewScanner(nil, remoteLibrary, alerter, scanOptions)
+			s := NewScanner(remoteLibrary, alerter, scanOptions)
 			got, err := s.Resources()
 			assert.Equal(tt, err, c.wantErr)
 			if err != nil {
@@ -1212,7 +1215,7 @@ func TestEC2Subnet(t *testing.T) {
 			remoteLibrary.AddEnumerator(aws.NewEC2SubnetEnumerator(repo, factory))
 			remoteLibrary.AddDetailsFetcher(resourceaws.AwsSubnetResourceType, common.NewGenericDetailsFetcher(resourceaws.AwsSubnetResourceType, provider, deserializer))
 
-			s := NewScanner(nil, remoteLibrary, alerter, scanOptions)
+			s := NewScanner(remoteLibrary, alerter, scanOptions)
 			got, err := s.Resources()
 			assert.Equal(tt, err, c.wantErr)
 			if err != nil {
@@ -1324,7 +1327,7 @@ func TestEC2DefaultSubnet(t *testing.T) {
 			remoteLibrary.AddEnumerator(aws.NewEC2DefaultSubnetEnumerator(repo, factory))
 			remoteLibrary.AddDetailsFetcher(resourceaws.AwsDefaultSubnetResourceType, common.NewGenericDetailsFetcher(resourceaws.AwsDefaultSubnetResourceType, provider, deserializer))
 
-			s := NewScanner(nil, remoteLibrary, alerter, scanOptions)
+			s := NewScanner(remoteLibrary, alerter, scanOptions)
 			got, err := s.Resources()
 			assert.Equal(tt, err, c.wantErr)
 			if err != nil {
@@ -1423,7 +1426,7 @@ func TestEC2RouteTable(t *testing.T) {
 			remoteLibrary.AddEnumerator(aws.NewEC2RouteTableEnumerator(repo, factory))
 			remoteLibrary.AddDetailsFetcher(resourceaws.AwsRouteTableResourceType, common.NewGenericDetailsFetcher(resourceaws.AwsRouteTableResourceType, provider, deserializer))
 
-			s := NewScanner(nil, remoteLibrary, alerter, scanOptions)
+			s := NewScanner(remoteLibrary, alerter, scanOptions)
 			got, err := s.Resources()
 			assert.Equal(tt, err, c.wantErr)
 			if err != nil {
@@ -1522,7 +1525,7 @@ func TestEC2DefaultRouteTable(t *testing.T) {
 			remoteLibrary.AddEnumerator(aws.NewEC2DefaultRouteTableEnumerator(repo, factory))
 			remoteLibrary.AddDetailsFetcher(resourceaws.AwsDefaultRouteTableResourceType, aws.NewEC2DefaultRouteTableDetailsFetcher(provider, deserializer))
 
-			s := NewScanner(nil, remoteLibrary, alerter, scanOptions)
+			s := NewScanner(remoteLibrary, alerter, scanOptions)
 			got, err := s.Resources()
 			assert.Equal(tt, err, c.wantErr)
 			if err != nil {
@@ -1586,7 +1589,7 @@ func TestVpcSecurityGroup(t *testing.T) {
 		t.Run(c.test, func(tt *testing.T) {
 			shouldUpdate := c.dirName == *goldenfile.Update
 
-			session := session.Must(session.NewSessionWithOptions(session.Options{
+			sess := session.Must(session.NewSessionWithOptions(session.Options{
 				SharedConfigState: session.SharedConfigEnable,
 			}))
 
@@ -1615,13 +1618,13 @@ func TestVpcSecurityGroup(t *testing.T) {
 					t.Fatal(err)
 				}
 				provider.ShouldUpdate()
-				repo = repository.NewEC2Repository(session, cache.New(0))
+				repo = repository.NewEC2Repository(sess, cache.New(0))
 			}
 
 			remoteLibrary.AddEnumerator(aws.NewVPCSecurityGroupEnumerator(repo, factory))
 			remoteLibrary.AddDetailsFetcher(resourceaws.AwsSecurityGroupResourceType, common.NewGenericDetailsFetcher(resourceaws.AwsSecurityGroupResourceType, provider, deserializer))
 
-			s := NewScanner(nil, remoteLibrary, alerter, scanOptions)
+			s := NewScanner(remoteLibrary, alerter, scanOptions)
 			got, err := s.Resources()
 			assert.Equal(tt, err, c.wantErr)
 			if err != nil {
@@ -1681,6 +1684,438 @@ func TestVpcDefaultSecurityGroup(t *testing.T) {
 	factory := terraform.NewTerraformResourceFactory(schemaRepository)
 	deserializer := resource.NewDeserializer(factory)
 
+	for _, c := range tests {
+		t.Run(c.test, func(tt *testing.T) {
+			shouldUpdate := c.dirName == *goldenfile.Update
+
+			sess := session.Must(session.NewSessionWithOptions(session.Options{
+				SharedConfigState: session.SharedConfigEnable,
+			}))
+
+			scanOptions := ScannerOptions{Deep: true}
+			providerLibrary := terraform.NewProviderLibrary()
+			remoteLibrary := common.NewRemoteLibrary()
+
+			// Initialize mocks
+			alerter := &mocks.AlerterInterface{}
+			alerter.On("SendAlert", mock.Anything, mock.Anything).Maybe().Return()
+			fakeRepo := &repository.MockEC2Repository{}
+			c.mocks(fakeRepo)
+			var repo repository.EC2Repository = fakeRepo
+			providerVersion := "3.19.0"
+			realProvider, err := terraform2.InitTestAwsProvider(providerLibrary, providerVersion)
+			if err != nil {
+				t.Fatal(err)
+			}
+			provider := terraform2.NewFakeTerraformProvider(realProvider)
+			provider.WithResponse(c.dirName)
+
+			// Replace mock by real resources if we are in update mode
+			if shouldUpdate {
+				err := realProvider.Init()
+				if err != nil {
+					t.Fatal(err)
+				}
+				provider.ShouldUpdate()
+				repo = repository.NewEC2Repository(sess, cache.New(0))
+			}
+
+			remoteLibrary.AddEnumerator(aws.NewVPCDefaultSecurityGroupEnumerator(repo, factory))
+			remoteLibrary.AddDetailsFetcher(resourceaws.AwsDefaultSecurityGroupResourceType, common.NewGenericDetailsFetcher(resourceaws.AwsDefaultSecurityGroupResourceType, provider, deserializer))
+
+			s := NewScanner(remoteLibrary, alerter, scanOptions)
+			got, err := s.Resources()
+			assert.Equal(tt, err, c.wantErr)
+			if err != nil {
+				return
+			}
+			test.TestAgainstGoldenFile(got, resourceaws.AwsDefaultSecurityGroupResourceType, c.dirName, provider, deserializer, shouldUpdate, tt)
+		})
+	}
+}
+
+func TestEC2NatGateway(t *testing.T) {
+	tests := []struct {
+		test    string
+		dirName string
+		mocks   func(repository *repository.MockEC2Repository)
+		wantErr error
+	}{
+		{
+			test:    "no nat gateways",
+			dirName: "aws_ec2_nat_gateway_empty",
+			mocks: func(repository *repository.MockEC2Repository) {
+				repository.On("ListAllNatGateways").Return([]*ec2.NatGateway{}, nil)
+			},
+		},
+		{
+			test:    "single nat gateway",
+			dirName: "aws_ec2_nat_gateway_single",
+			mocks: func(repository *repository.MockEC2Repository) {
+				repository.On("ListAllNatGateways").Return([]*ec2.NatGateway{
+					{NatGatewayId: awssdk.String("nat-0a5408508b19ef490")},
+				}, nil)
+			},
+		},
+		{
+			test:    "cannot list nat gateways",
+			dirName: "aws_ec2_nat_gateway_list",
+			mocks: func(repository *repository.MockEC2Repository) {
+				repository.On("ListAllNatGateways").Return(nil, awserr.NewRequestFailure(nil, 403, ""))
+			},
+			wantErr: nil,
+		},
+	}
+
+	schemaRepository := testresource.InitFakeSchemaRepository("aws", "3.19.0")
+	resourceaws.InitResourcesMetadata(schemaRepository)
+	factory := terraform.NewTerraformResourceFactory(schemaRepository)
+	deserializer := resource.NewDeserializer(factory)
+
+	for _, c := range tests {
+		t.Run(c.test, func(tt *testing.T) {
+			shouldUpdate := c.dirName == *goldenfile.Update
+
+			sess := session.Must(session.NewSessionWithOptions(session.Options{
+				SharedConfigState: session.SharedConfigEnable,
+			}))
+
+			scanOptions := ScannerOptions{Deep: true}
+			providerLibrary := terraform.NewProviderLibrary()
+			remoteLibrary := common.NewRemoteLibrary()
+
+			// Initialize mocks
+			alerter := &mocks.AlerterInterface{}
+			alerter.On("SendAlert", mock.Anything, mock.Anything).Maybe().Return()
+			fakeRepo := &repository.MockEC2Repository{}
+			c.mocks(fakeRepo)
+			var repo repository.EC2Repository = fakeRepo
+			providerVersion := "3.19.0"
+			realProvider, err := terraform2.InitTestAwsProvider(providerLibrary, providerVersion)
+			if err != nil {
+				t.Fatal(err)
+			}
+			provider := terraform2.NewFakeTerraformProvider(realProvider)
+			provider.WithResponse(c.dirName)
+
+			// Replace mock by real resources if we are in update mode
+			if shouldUpdate {
+				err := realProvider.Init()
+				if err != nil {
+					t.Fatal(err)
+				}
+				provider.ShouldUpdate()
+				repo = repository.NewEC2Repository(sess, cache.New(0))
+			}
+
+			remoteLibrary.AddEnumerator(aws.NewEC2NatGatewayEnumerator(repo, factory))
+			remoteLibrary.AddDetailsFetcher(resourceaws.AwsNatGatewayResourceType, common.NewGenericDetailsFetcher(resourceaws.AwsNatGatewayResourceType, provider, deserializer))
+
+			s := NewScanner(remoteLibrary, alerter, scanOptions)
+			got, err := s.Resources()
+			assert.Equal(tt, err, c.wantErr)
+			if err != nil {
+				return
+			}
+			test.TestAgainstGoldenFile(got, resourceaws.AwsNatGatewayResourceType, c.dirName, provider, deserializer, shouldUpdate, tt)
+		})
+	}
+}
+
+func TestEC2Route(t *testing.T) {
+	tests := []struct {
+		test    string
+		dirName string
+		mocks   func(repository *repository.MockEC2Repository)
+		wantErr error
+	}{
+		{
+			// route table with no routes case is not possible
+			// as a default route will always be present in each route table
+			test:    "no routes",
+			dirName: "aws_ec2_route_empty",
+			mocks: func(repository *repository.MockEC2Repository) {
+				repository.On("ListAllRouteTables").Return([]*ec2.RouteTable{}, nil)
+			},
+		},
+		{
+			test:    "multiple routes (mixed default_route_table and route_table)",
+			dirName: "aws_ec2_route_multiple",
+			mocks: func(repository *repository.MockEC2Repository) {
+				repository.On("ListAllRouteTables").Return([]*ec2.RouteTable{
+					{
+						RouteTableId: awssdk.String("rtb-096bdfb69309c54c3"), // table1
+						Routes: []*ec2.Route{
+							{
+								DestinationCidrBlock: awssdk.String("10.0.0.0/16"),
+								Origin:               awssdk.String("CreateRouteTable"), // default route
+							},
+							{
+								DestinationCidrBlock: awssdk.String("1.1.1.1/32"),
+								GatewayId:            awssdk.String("igw-030e74f73bd67f21b"),
+								Origin:               awssdk.String("CreateRoute"),
+							},
+							{
+								DestinationIpv6CidrBlock: awssdk.String("::/0"),
+								GatewayId:                awssdk.String("igw-030e74f73bd67f21b"),
+								Origin:                   awssdk.String("CreateRoute"),
+							},
+						},
+					},
+					{
+						RouteTableId: awssdk.String("rtb-0169b0937fd963ddc"), // table2
+						Routes: []*ec2.Route{
+							{
+								DestinationCidrBlock: awssdk.String("10.0.0.0/16"),
+								Origin:               awssdk.String("CreateRouteTable"), // default route
+							},
+							{
+								DestinationCidrBlock: awssdk.String("0.0.0.0/0"),
+								GatewayId:            awssdk.String("igw-030e74f73bd67f21b"),
+								Origin:               awssdk.String("CreateRoute"),
+							},
+							{
+								DestinationIpv6CidrBlock: awssdk.String("::/0"),
+								GatewayId:                awssdk.String("igw-030e74f73bd67f21b"),
+								Origin:                   awssdk.String("CreateRoute"),
+							},
+						},
+					},
+					{
+						RouteTableId: awssdk.String("rtb-02780c485f0be93c5"), // default_table
+						VpcId:        awssdk.String("vpc-09fe5abc2309ba49d"),
+						Associations: []*ec2.RouteTableAssociation{
+							{
+								Main: awssdk.Bool(true),
+							},
+						},
+						Routes: []*ec2.Route{
+							{
+								DestinationCidrBlock: awssdk.String("10.0.0.0/16"),
+								Origin:               awssdk.String("CreateRouteTable"), // default route
+							},
+							{
+								DestinationCidrBlock: awssdk.String("10.1.1.0/24"),
+								GatewayId:            awssdk.String("igw-030e74f73bd67f21b"),
+								Origin:               awssdk.String("CreateRoute"),
+							},
+							{
+								DestinationCidrBlock: awssdk.String("10.1.2.0/24"),
+								GatewayId:            awssdk.String("igw-030e74f73bd67f21b"),
+								Origin:               awssdk.String("CreateRoute"),
+							},
+						},
+					},
+					{
+						RouteTableId: awssdk.String(""), // table3
+						Routes: []*ec2.Route{
+							{
+								DestinationCidrBlock: awssdk.String("10.0.0.0/16"),
+								Origin:               awssdk.String("CreateRouteTable"), // default route
+							},
+						},
+					},
+				}, nil)
+			},
+		},
+		{
+			test:    "cannot list routes",
+			dirName: "aws_ec2_route_list",
+			mocks: func(repository *repository.MockEC2Repository) {
+				repository.On("ListAllRouteTables").Return(nil, awserr.NewRequestFailure(nil, 403, ""))
+			},
+			wantErr: nil,
+		},
+	}
+
+	schemaRepository := testresource.InitFakeSchemaRepository("aws", "3.19.0")
+	resourceaws.InitResourcesMetadata(schemaRepository)
+	factory := terraform.NewTerraformResourceFactory(schemaRepository)
+	deserializer := resource.NewDeserializer(factory)
+
+	for _, c := range tests {
+		t.Run(c.test, func(tt *testing.T) {
+			shouldUpdate := c.dirName == *goldenfile.Update
+
+			sess := session.Must(session.NewSessionWithOptions(session.Options{
+				SharedConfigState: session.SharedConfigEnable,
+			}))
+
+			scanOptions := ScannerOptions{Deep: true}
+			providerLibrary := terraform.NewProviderLibrary()
+			remoteLibrary := common.NewRemoteLibrary()
+
+			// Initialize mocks
+			alerter := &mocks.AlerterInterface{}
+			alerter.On("SendAlert", mock.Anything, mock.Anything).Maybe().Return()
+			fakeRepo := &repository.MockEC2Repository{}
+			c.mocks(fakeRepo)
+			var repo repository.EC2Repository = fakeRepo
+			providerVersion := "3.19.0"
+			realProvider, err := terraform2.InitTestAwsProvider(providerLibrary, providerVersion)
+			if err != nil {
+				t.Fatal(err)
+			}
+			provider := terraform2.NewFakeTerraformProvider(realProvider)
+			provider.WithResponse(c.dirName)
+
+			// Replace mock by real resources if we are in update mode
+			if shouldUpdate {
+				err := realProvider.Init()
+				if err != nil {
+					t.Fatal(err)
+				}
+				provider.ShouldUpdate()
+				repo = repository.NewEC2Repository(sess, cache.New(0))
+			}
+
+			remoteLibrary.AddEnumerator(aws.NewEC2RouteEnumerator(repo, factory))
+			remoteLibrary.AddDetailsFetcher(resourceaws.AwsRouteResourceType, aws.NewEC2RouteDetailsFetcher(provider, deserializer))
+
+			s := NewScanner(remoteLibrary, alerter, scanOptions)
+			got, err := s.Resources()
+			assert.Equal(tt, err, c.wantErr)
+			if err != nil {
+				return
+			}
+			test.TestAgainstGoldenFile(got, resourceaws.AwsRouteResourceType, c.dirName, provider, deserializer, shouldUpdate, tt)
+		})
+	}
+}
+
+func TestVpcSecurityGroupRule(t *testing.T) {
+
+	tests := []struct {
+		test    string
+		dirName string
+		mocks   func(repository *repository.MockEC2Repository)
+		wantErr error
+	}{
+		{
+			test:    "no security group rules",
+			dirName: "vpc_security_group_rule_empty",
+			mocks: func(client *repository.MockEC2Repository) {
+				client.On("ListAllSecurityGroups").Once().Return([]*ec2.SecurityGroup{
+					{
+						GroupId:             awssdk.String("sg-0254c038e32f25530"),
+						IpPermissions:       []*ec2.IpPermission{},
+						IpPermissionsEgress: []*ec2.IpPermission{},
+					},
+				}, nil, nil)
+			},
+			wantErr: nil,
+		},
+		{
+			test:    "with security group rules",
+			dirName: "vpc_security_group_rule_multiple",
+			mocks: func(client *repository.MockEC2Repository) {
+				client.On("ListAllSecurityGroups").Once().Return([]*ec2.SecurityGroup{
+					{
+						GroupId: awssdk.String("sg-0254c038e32f25530"),
+						IpPermissions: []*ec2.IpPermission{
+							{
+								FromPort:   awssdk.Int64(0),
+								ToPort:     awssdk.Int64(65535),
+								IpProtocol: awssdk.String("tcp"),
+								UserIdGroupPairs: []*ec2.UserIdGroupPair{
+									{
+										GroupId: awssdk.String("sg-0254c038e32f25530"),
+									},
+									{
+										GroupId: awssdk.String("sg-9e0204ff"),
+									},
+								},
+							},
+							{
+								IpProtocol: awssdk.String("-1"),
+								IpRanges: []*ec2.IpRange{
+									{
+										CidrIp: awssdk.String("1.2.0.0/16"),
+									},
+									{
+										CidrIp: awssdk.String("5.6.7.0/24"),
+									},
+								},
+								Ipv6Ranges: []*ec2.Ipv6Range{
+									{
+										CidrIpv6: awssdk.String("::/0"),
+									},
+								},
+							},
+						},
+						IpPermissionsEgress: []*ec2.IpPermission{
+							{
+								IpProtocol: awssdk.String("-1"),
+								IpRanges: []*ec2.IpRange{
+									{
+										CidrIp: awssdk.String("0.0.0.0/0"),
+									},
+								},
+								Ipv6Ranges: []*ec2.Ipv6Range{
+									{
+										CidrIpv6: awssdk.String("::/0"),
+									},
+								},
+							},
+						},
+					},
+					{
+						GroupId: awssdk.String("sg-0cc8b3c3c2851705a"),
+						IpPermissions: []*ec2.IpPermission{
+							{
+								FromPort:   awssdk.Int64(443),
+								ToPort:     awssdk.Int64(443),
+								IpProtocol: awssdk.String("tcp"),
+								IpRanges: []*ec2.IpRange{
+									{
+										CidrIp: awssdk.String("0.0.0.0/0"),
+									},
+								},
+							},
+						},
+						IpPermissionsEgress: []*ec2.IpPermission{
+							{
+								IpProtocol: awssdk.String("-1"),
+								IpRanges: []*ec2.IpRange{
+									{
+										CidrIp: awssdk.String("0.0.0.0/0"),
+									},
+								},
+								Ipv6Ranges: []*ec2.Ipv6Range{
+									{
+										CidrIpv6: awssdk.String("::/0"),
+									},
+								},
+							},
+							{
+								IpProtocol: awssdk.String("5"),
+								IpRanges: []*ec2.IpRange{
+									{
+										CidrIp: awssdk.String("0.0.0.0/0"),
+									},
+								},
+							},
+						},
+					},
+				}, nil, nil)
+			},
+			wantErr: nil,
+		},
+		{
+			test:    "cannot list security group rules",
+			dirName: "vpc_security_group_rule_empty",
+			mocks: func(client *repository.MockEC2Repository) {
+				client.On("ListAllSecurityGroups").Once().Return(nil, nil, awserr.NewRequestFailure(nil, 403, ""))
+			},
+			wantErr: nil,
+		},
+	}
+
+	schemaRepository := testresource.InitFakeSchemaRepository("aws", "3.19.0")
+	resourceaws.InitResourcesMetadata(schemaRepository)
+	factory := terraform.NewTerraformResourceFactory(schemaRepository)
+	deserializer := resource.NewDeserializer(factory)
+
 	for _, c := range tests {
 		t.Run(c.test, func(tt *testing.T) {
 			shouldUpdate := c.dirName == *goldenfile.Update
@@ -1717,16 +2152,16 @@ func TestVpcDefaultSecurityGroup(t *testing.T) {
 				repo = repository.NewEC2Repository(session, cache.New(0))
 			}
 
-			remoteLibrary.AddEnumerator(aws.NewVPCDefaultSecurityGroupEnumerator(repo, factory))
-			remoteLibrary.AddDetailsFetcher(resourceaws.AwsDefaultSecurityGroupResourceType, common.NewGenericDetailsFetcher(resourceaws.AwsDefaultSecurityGroupResourceType, provider, deserializer))
+			remoteLibrary.AddEnumerator(aws.NewVPCSecurityGroupRuleEnumerator(repo, factory))
+			remoteLibrary.AddDetailsFetcher(resourceaws.AwsSecurityGroupRuleResourceType, aws.NewVPCSecurityGroupRuleDetailsFetcher(provider, deserializer))
 
-			s := NewScanner(nil, remoteLibrary, alerter, scanOptions)
+			s := NewScanner(remoteLibrary, alerter, scanOptions)
 			got, err := s.Resources()
-			assert.Equal(tt, err, c.wantErr)
+			assert.Equal(tt, c.wantErr, err)
 			if err != nil {
 				return
 			}
-			test.TestAgainstGoldenFile(got, resourceaws.AwsDefaultSecurityGroupResourceType, c.dirName, provider, deserializer, shouldUpdate, tt)
+			test.TestAgainstGoldenFile(got, resourceaws.AwsSecurityGroupRuleResourceType, c.dirName, provider, deserializer, shouldUpdate, tt)
 		})
 	}
 }
