@@ -11,7 +11,7 @@ func TestAcc_Aws_IamRole(t *testing.T) {
 	acceptance.Run(t, acceptance.AccTestCase{
 		TerraformVersion: "0.14.9",
 		Paths:            []string{"./testdata/acc/aws_iam_role"},
-		Args:             []string{"scan", "--filter", "Type=='aws_iam_role'"},
+		Args:             []string{"scan", "--filter", "Type=='aws_iam_role'", "--tf-provider-version", "3.45.0", "--deep"},
 		Checks: []acceptance.AccCheck{
 			{
 				Env: map[string]string{
