@@ -11,7 +11,7 @@ func TestAcc_AwsInternetGateway(t *testing.T) {
 	acceptance.Run(t, acceptance.AccTestCase{
 		TerraformVersion: "0.14.9",
 		Paths:            []string{"./testdata/acc/aws_internet_gateway"},
-		Args:             []string{"scan", "--filter", "Type=='aws_internet_gateway'"},
+		Args:             []string{"scan", "--filter", "Type=='aws_internet_gateway'", "--deep"},
 		Checks: []acceptance.AccCheck{
 			{
 				Env: map[string]string{
