@@ -13,7 +13,7 @@ func initAwsRoute53HealthCheckMetaData(resourceSchemaRepository resource.SchemaR
 		val := res.Attrs
 		attrs := make(map[string]string)
 		if tags := val.GetMap("tags"); tags != nil {
-			if name, ok := tags["name"]; ok {
+			if name, ok := tags["Name"]; ok {
 				attrs["Name"] = name.(string)
 			}
 		}
