@@ -11,7 +11,7 @@ func TestAcc_AwsRouteTableAssociation(t *testing.T) {
 	acceptance.Run(t, acceptance.AccTestCase{
 		TerraformVersion: "0.14.9",
 		Paths:            []string{"./testdata/acc/aws_route_table_association"},
-		Args:             []string{"scan", "--filter", "Type=='aws_route_table_association'"},
+		Args:             []string{"scan", "--filter", "Type=='aws_route_table_association'", "--deep"},
 		Checks: []acceptance.AccCheck{
 			{
 				Env: map[string]string{
