@@ -11,7 +11,7 @@ func TestAcc_AwsRoute(t *testing.T) {
 	acceptance.Run(t, acceptance.AccTestCase{
 		TerraformVersion: "0.14.9",
 		Paths:            []string{"./testdata/acc/aws_route"},
-		Args:             []string{"scan", "--filter", "Type=='aws_route'"},
+		Args:             []string{"scan", "--filter", "Type=='aws_route'", "--tf-provider-version", "3.44.0", "--deep"},
 		Checks: []acceptance.AccCheck{
 			{
 				Env: map[string]string{
