@@ -16,7 +16,7 @@ func TestAcc_AwsSNSTopicSubscription(t *testing.T) {
 	acceptance.Run(t, acceptance.AccTestCase{
 		TerraformVersion: "0.14.9",
 		Paths:            []string{"./testdata/acc/aws_sns_topic_subscription"},
-		Args:             []string{"scan", "--filter", "Type=='aws_sns_topic_subscription'"},
+		Args:             []string{"scan", "--filter", "Type=='aws_sns_topic_subscription'", "--deep"},
 		Checks: []acceptance.AccCheck{
 			{
 				Env: map[string]string{
